@@ -268,7 +268,7 @@ class DataLoader:
             self._conf.column.dtype_dict = self.update_dtype_dict(self._conf.data.validation_location,
                                                                   dtype_trial_nrows=self._conf.column.dtype_trial_nrows)
 
-        if self._conf.data.validation_sample_size:
+        if self._conf.data.validation_sample_size and self._conf.data.validation_format == "csv":
             logging.info("Sampling %i rows from the validation dataset...", self._conf.data.validation_sample_size)
             self.validation_nrows = self.get_file_num_rows(self._conf.data.validation_location)
 
@@ -291,6 +291,14 @@ class DataLoader:
         if self.skiprows:
             self.df.reset_index(drop=True, inplace=True)
 
+        if self._conf.data.validation_sample_size and self._conf.data.validation_format != "csv":
+            logging.info("Sampling %i rows from the validation dataset...", self._conf.data.validation_sample_size)
+            self.df = self.df.sample(n=self._conf.data.validation_sample_size,
+                                     replace=False,
+                                     random_state=self._conf.data.validation_sample_seed)
+            # the newer version of pandas has the option "ignore_index", we can update when we use the newer versions
+            self.df.reset_index(drop=True, inplace=True)
+
         return self.df
 
     def load_test_from_file(self, **kwargs):
